getB-methods: Methods for Function getB in Package 'unmarked'

getB-methodsR Documentation

Methods for Function getB in Package ‘unmarked’

Description

Methods for function getB in Package ‘unmarked’. These methods return a matrix of probabilities detections were certain for occupancy models that account for false positives.


unmarked documentation built on Aug. 20, 2026, 9:07 a.m.