unmarkedMultFrame(y, siteCovs, obsCovs, numPrimary, yearlySiteCovs,
plotArea)colext and hmm.For a study with M sites, T years, and a maximum of J observations per site-year, the data
are shaped as follows. y is an $M \times TJ$ matrix, with each row corresponding to a site.
siteCovs is a data frame with $M$ rows.
yearlySiteCovs is a data frame with $MT$ rows which are in site-major, year-minor order.
obsCovs is a data frame with $MTJ$ rows, which are ordered by site-year-observation, so that a
column of obsCovs corresponds to numPrimary.
If the data are in long format, the convenience function formatMult is useful for creating
the unmarkedMultFrame.