These models generalize the Royle (2004) N-mixture model by relaxing the
closure assumption. A basic form of the model
(dynamics='constant' and mixture='P') treats initial
abundance at site i as Poisson distributed: \(N_{i,1} \sim
\text{Poisson}(\lambda)\). The latent
abundance state following the initial sampling period arises from a
Markovian process in which survivors are modeled as \(S_{i,t} \sim
\text{Binomial}(N_{i,t-1}, \omega)\), and recruits follow \(G_{i,t} \sim
\text{Poisson}(\gamma)\). Abundance is then
\(N_{i,t}=S_{i,t}+G_{i,t}\).
The detection process is modeled as binomial: \(y_{i,j,t} \sim
Binomial(N_{i,t}, p)\).
The latent abundance distribution during the initial time period can be
set as a Poisson, negative binomial, or zero-inflated Poisson random
variable, depending on the setting of the mixture argument,
mixture = "P", mixture = "NB", mixture = "ZIP"
respectively. For the first two distributions, the mean of
\(N_{i,1}\) is \(\lambda\). In the negative
binomial case, an additional parameter, \(\alpha\), describes
dispersion (lower \(\alpha\) implies higher variance). For the
ZIP distribution, the mean is \(\lambda(1-\psi)\),
where \(\psi\) is the zero-inflation parameter.
Alternative population dynamics can be specified
using the dynamics and immigration arguments.
When dynamics='autoreg',
\(E(recruits)=\gamma N_{i,t-1}\) such that
\(\gamma\) is the per-capita recruitment rate. In the case of
dynamics='notrend',
\(E(recruits)=\lambda (1-\omega)\)
forcing an equilibrium condition (no temporal trend in abundance).
Alternative dynamics focus directly on the expected value of abundance
at the subsequent time period, avoiding the decomposition into survivors
and recruits. Geometric growth can be specified by
dynamics='trend', with \(N_{i,t} \sim
\text{Poisson}(\gamma N_{i,t-1})\),
where \(\gamma\) in this case is finite rate of increase
(normally referred to as lambda). Dynamics "ricker" and "gompertz" are
stochastic models of density-dependent population growth. "ricker" is the
Ricker-logistic model, \(N_{i,t} \sim
\text{Poisson}(N_{i,t-1}\exp(\gamma (1-N_{i,t-1}/\omega)))\) ,
where \(\gamma\) is the maximum instantaneous population
growth rate (normally referred to as r) and \(\omega\) is
the equilibrium abundance (normally referred to as K). "gompertz"
is a modified version of the Gompertz-logistic model,
\(N_{i,t} \sim
\text{Poisson}(N_{i,t-1}*exp(\gamma*(1-\log(N_{i,t-1}+1)/\log(\omega+1))))\),
where the interpretations of \(\gamma\) and
\(\omega\) are similar to the Ricker model.
When immigration=TRUE, \(\iota\) is the number of
immigrants per site and year.
When immigration is set to TRUE and dynamics is set to "autoreg", the model
will separately estimate birth rate \(\gamma\) and number of
immigrants \(\iota\). When immigration is set to TRUE and
dynamics is set to "trend", "ricker", or "gompertz", the model will
separately estimate local contributions to
population growth (\(\gamma\) and \(\omega\)) and
number of immigrants (\(\iota\)).
\(\lambda_i\), \(\gamma_{it}\), and
\(\iota_{it}\) are modeled using the the log link.
\(p_{ijt}\) is modeled using the logit link.
\(\omega_{it}\) is either modeled using the logit link (for
"constant", "autoreg", or "notrend" dynamics) or the log link (for "ricker"
or "gompertz" dynamics). For "trend" dynamics, \(\omega_{it}\)
is not modeled.